#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-xlib
version:                2.0.14
visibility:             public
id:                     gi-xlib-2.0.14-5Rfv1QnH6QD7vnXDgeS3Gp
key:                    gi-xlib-2.0.14-5Rfv1QnH6QD7vnXDgeS3Gp
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               xlib bindings
description:            Bindings for xlib, autogenerated by haskell-gi.
category:               Bindings
abi:                    501eaca4ba4031677cc2867124bf924c
exposed:                True
exposed-modules:
    GI.Xlib GI.Xlib.Config GI.Xlib.Functions GI.Xlib.Structs
    GI.Xlib.Structs.Display GI.Xlib.Structs.Screen
    GI.Xlib.Structs.Visual GI.Xlib.Structs.XConfigureEvent
    GI.Xlib.Structs.XFontStruct GI.Xlib.Structs.XImage
    GI.Xlib.Structs.XTrapezoid GI.Xlib.Structs.XVisualInfo
    GI.Xlib.Structs.XWindowAttributes GI.Xlib.Unions
    GI.Xlib.Unions.XEvent

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-xlib-2.0.14
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-xlib-2.0.14 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-xlib-2.0.14 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-xlib
hs-libraries:           HSgi-xlib-2.0.14-5Rfv1QnH6QD7vnXDgeS3Gp
extra-libraries:        X11
extra-libraries-static: X11 pthread xcb Xau Xdmcp
include-dirs:           /usr/include
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    haskell-gi-0.26.17-5ChzDzvktsV6dPlKtq3FgN
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-xlib/html/gi-xlib.haddock
haddock-html:           /usr/share/doc/haskell-gi-xlib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

